==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/components/floating_toolbar/background_color/FloatingToolbarBackgroundColorPanel.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/components/floating_toolbar/background_color/FloatingToolbarBackgroundColorPanel.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-state', 'frontend-js-metal-web$metal-soy', '../common/FloatingToolbarColorPicker.es', './FloatingToolbarBackgroundColorPanelDelegateTemplate.soy', '../../../utils/rowConstants', '../../../actions/saveChanges.es', '../../../store/ConnectedComponent.es', './FloatingToolbarBackgroundColorPanel.soy', '../../../actions/actions.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.FloatingToolbarBackgroundColorPanel = exports.ConnectedFloatingToolbarBackgroundColorPanel = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  require("../common/FloatingToolbarColorPicker.es");

  require("./FloatingToolbarBackgroundColorPanelDelegateTemplate.soy");

  var _rowConstants = require("../../../utils/rowConstants");

  var _saveChanges = require("../../../actions/saveChanges.es");

  var _ConnectedComponent = _interopRequireDefault(require("../../../store/ConnectedComponent.es"));

  var _FloatingToolbarBackgroundColorPanel = _interopRequireDefault(require("./FloatingToolbarBackgroundColorPanel.soy"));

  var _actions = require("../../../actions/actions.es");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FloatingToolbarBackgroundColorPanel
   */
  var FloatingToolbarBackgroundColorPanel =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FloatingToolbarBackgroundColorPanel, _Component);

    function FloatingToolbarBackgroundColorPanel() {
      _classCallCheck(this, FloatingToolbarBackgroundColorPanel);

      return _possibleConstructorReturn(this, _getPrototypeOf(FloatingToolbarBackgroundColorPanel).apply(this, arguments));
    }

    _createClass(FloatingToolbarBackgroundColorPanel, [{
      key: "_handleClearButtonClick",

      /**
       * Handle Clear button click
       * @private
       * @review
       */
      value: function _handleClearButtonClick() {
        this._updateRowConfig(_defineProperty({}, _rowConstants.CONFIG_KEYS.backgroundColorCssClass, ''));
      }
      /**
       * Handle BackgroundColor button click
       * @param {Event} event
       * @private
       * @review
       */

    }, {
      key: "_handleBackgroundColorButtonClick",
      value: function _handleBackgroundColorButtonClick(event) {
        this._updateRowConfig(_defineProperty({}, _rowConstants.CONFIG_KEYS.backgroundColorCssClass, event.color));
      }
      /**
       * Updates row configuration
       * @param {object} config Row configuration
       * @private
       * @review
       */

    }, {
      key: "_updateRowConfig",
      value: function _updateRowConfig(config) {
        this.store.dispatch((0, _saveChanges.enableSavingChangesStatusAction)()).dispatch({
          config: config,
          rowId: this.itemId,
          type: _actions.UPDATE_ROW_CONFIG
        }).dispatch((0, _saveChanges.updateLastSaveDateAction)()).dispatch((0, _saveChanges.disableSavingChangesStatusAction)());
      }
    }]);

    return FloatingToolbarBackgroundColorPanel;
  }(_metalComponent.default);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FloatingToolbarBackgroundColorPanel = FloatingToolbarBackgroundColorPanel;
  FloatingToolbarBackgroundColorPanel.STATE = {
    /**
     * @default undefined
     * @memberof FloatingToolbarBackgroundColorPanel
     * @review
     * @type {!string}
     */
    itemId: _metalState.Config.string().required()
  };
  var ConnectedFloatingToolbarBackgroundColorPanel = (0, _ConnectedComponent.default)(FloatingToolbarBackgroundColorPanel, ['themeColorsCssClasses']);
  exports.ConnectedFloatingToolbarBackgroundColorPanel = ConnectedFloatingToolbarBackgroundColorPanel;

  _metalSoy.default.register(ConnectedFloatingToolbarBackgroundColorPanel, _FloatingToolbarBackgroundColorPanel.default);

  var _default = ConnectedFloatingToolbarBackgroundColorPanel;
  exports.default = _default;
  //# sourceMappingURL=FloatingToolbarBackgroundColorPanel.es.js.map
});
//# sourceMappingURL=FloatingToolbarBackgroundColorPanel.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/floating_toolbar/background_color/FloatingToolbarBackgroundColorPanel.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/floating_toolbar/background_color/FloatingToolbarBackgroundColorPanel.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', '../common/FloatingToolbarColorPicker.es', './FloatingToolbarBackgroundColorPanelDelegateTemplate.soy', '../../../actions/updateRowConfig.es', '../../../store/ConnectedComponent.es', '../../../utils/rowConstants', './FloatingToolbarBackgroundColorPanel.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.FloatingToolbarBackgroundColorPanel = exports.ConnectedFloatingToolbarBackgroundColorPanel = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("../common/FloatingToolbarColorPicker.es");

  require("./FloatingToolbarBackgroundColorPanelDelegateTemplate.soy");

  var _updateRowConfig2 = require("../../../actions/updateRowConfig.es");

  var _ConnectedComponent = _interopRequireDefault(require("../../../store/ConnectedComponent.es"));

  var _rowConstants = require("../../../utils/rowConstants");

  var _FloatingToolbarBackgroundColorPanel = _interopRequireDefault(require("./FloatingToolbarBackgroundColorPanel.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FloatingToolbarBackgroundColorPanel
   */
  var FloatingToolbarBackgroundColorPanel =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FloatingToolbarBackgroundColorPanel, _Component);

    function FloatingToolbarBackgroundColorPanel() {
      _classCallCheck(this, FloatingToolbarBackgroundColorPanel);

      return _possibleConstructorReturn(this, _getPrototypeOf(FloatingToolbarBackgroundColorPanel).apply(this, arguments));
    }

    _createClass(FloatingToolbarBackgroundColorPanel, [{
      key: "_handleClearButtonClick",

      /**
       * Handle Clear button click
       * @private
       * @review
       */
      value: function _handleClearButtonClick() {
        this._updateRowConfig(_defineProperty({}, _rowConstants.CONFIG_KEYS.backgroundColorCssClass, ''));
      }
      /**
       * Handle BackgroundColor button click
       * @param {Event} event
       * @private
       * @review
       */

    }, {
      key: "_handleBackgroundColorButtonClick",
      value: function _handleBackgroundColorButtonClick(event) {
        this._updateRowConfig(_defineProperty({}, _rowConstants.CONFIG_KEYS.backgroundColorCssClass, event.color));
      }
      /**
       * Updates row configuration
       * @param {object} config Row configuration
       * @private
       * @review
       */

    }, {
      key: "_updateRowConfig",
      value: function _updateRowConfig(config) {
        this.store.dispatch((0, _updateRowConfig2.updateRowConfigAction)(this.itemId, config));
      }
    }]);

    return FloatingToolbarBackgroundColorPanel;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FloatingToolbarBackgroundColorPanel = FloatingToolbarBackgroundColorPanel;
  FloatingToolbarBackgroundColorPanel.STATE = {
    /**
     * @default undefined
     * @memberof FloatingToolbarBackgroundColorPanel
     * @review
     * @type {!string}
     */
    itemId: _metalState.Config.string().required()
  };
  var ConnectedFloatingToolbarBackgroundColorPanel = (0, _ConnectedComponent["default"])(FloatingToolbarBackgroundColorPanel, ['themeColorsCssClasses']);
  exports.ConnectedFloatingToolbarBackgroundColorPanel = ConnectedFloatingToolbarBackgroundColorPanel;

  _metalSoy["default"].register(ConnectedFloatingToolbarBackgroundColorPanel, _FloatingToolbarBackgroundColorPanel["default"]);

  var _default = ConnectedFloatingToolbarBackgroundColorPanel;
  exports["default"] = _default;
  //# sourceMappingURL=FloatingToolbarBackgroundColorPanel.es.js.map
});
//# sourceMappingURL=FloatingToolbarBackgroundColorPanel.es.js.map
